<?php

namespace Growmatik\EDD;

class Discounts {

	public function index( $request ) {

		$discount_id = $request->get_param( 'id' );
		return $this->get_discount( $discount_id );
	}

	private function retrieve_discount( $id ) {
		$discount = edd_get_discount( $id );

		if ( ! ( $discount instanceof \EDD_Discount ) ) {
			return new \WP_Error( 'invalid', 'invalid_coupon', array( 'status' => 404 ) );
		}
		return $discount;
	}

	private function get_discount( $id ) {
		$gm_prefix     = \Growmatik\meta_site_prefix();
		$entity_prefix = "{$gm_prefix}_entity";
		$discount      = $this->retrieve_discount( $id );

		if ( ! ( $discount instanceof \EDD_Discount ) ) {
			return $discount;
		}

		$discount_data = array(
			'id'            => $discount->ID,
			'status'        => $discount->status,
			'code'          => $discount->code,
			'discount_type' => $discount->type,
			'coupon_amount' => $discount->amount,
			'product_ids'   => $discount->product_reqs,
			'entity_type'   => get_post_meta( $discount->ID, "{$entity_prefix}_type", true ),
			'entity_id'     => get_post_meta( $discount->ID, "{$entity_prefix}_id", true ),
		);

		$data = array( 'coupon' => $discount_data );

		$response = new \WP_REST_Response( $data );

		$response->set_status( 200 );

		return $response;

	}

	public function add( $request ) {

		$args                 = array();
		$existing_discount_id = null;

		$gm_prefix     = \Growmatik\meta_site_prefix();
		$entity_prefix = "{$gm_prefix}_entity";

		if ( $request->get_param( 'id' ) ) {
			$existing_discount_id = $request->get_param( 'id' );
			$args['code']         = edd_get_discount( $existing_discount_id )->code;
		} else {
			$args['code'] = strtoupper( substr( md5( wp_rand() ), 0, 12 ) );
		}

		$args['type']     = $this->validate_discount_type( $request->get_param( 'discount_type' ) );
		$args['amount']   = $request->get_param( 'coupon_amount' );
		$args['products'] = $request->get_param( 'product_ids' );

		// Only assign a name on coupon create; tenant may change the coupon name later so don't touch it on updates.
		if ( ! $existing_discount_id ) {
			$args['name'] = '(Growmatik) ' . $args['code'];
		} else {
			$discount     = new \EDD_Discount( $existing_discount_id );
			$args['name'] = $discount->get_name();
		}

		$new_discount_id = edd_store_discount( $args, $existing_discount_id );

		if ( ! $existing_discount_id ) {
			update_post_meta( $new_discount_id, "{$entity_prefix}_type", $request->get_param( 'entity_type' ) );
			update_post_meta( $new_discount_id, "{$entity_prefix}_id", $request->get_param( 'entity_id' ) );
			update_post_meta( $new_discount_id, "{$gm_prefix}_discount", 1 );
		}

		return $this->get_discount( $new_discount_id );
	}

	private function validate_discount_type( $discount_type ) {
		$valid_discount_types = array( 'percent', 'flat' );

		if ( ! in_array( $discount_type, $valid_discount_types, true ) ) {
			$discount_type = 'percent';
		}

		return $discount_type;
	}

	public function remove( $request ) {
		$discount_id = $request->get_param( 'id' );

		$discount = $this->retrieve_discount( $discount_id );

		if ( ! ( $discount instanceof \EDD_Discount ) ) {
			return $discount;
		}

		$response = $this->get_discount( $discount_id );

		edd_remove_discount( $discount_id );

		return $response;
	}

}
