<?php

namespace Growmatik\EDD;

class Routes {

	public function __construct() {
		if ( ! \Growmatik\is_edd_active() ) {
			return;
		}

		add_action( 'rest_api_init', array( $this, 'register_routes' ) );
	}

	public function register_routes() {
		$base_route              = 'growmatik/v1';
		$token_verifier_callback = array( new \Growmatik\Webhook\Verify_Token_Webhook(), 'verify_token' );

		register_rest_route(
			$base_route,
			'sync/products/edd',
			array(
				'methods'             => 'GET',
				'callback'            => array( new \Growmatik\EDD\Downloads(), 'index' ),
				'permission_callback' => $token_verifier_callback,
			)
		);

		register_rest_route(
			$base_route,
			'sync/orders/edd',
			array(
				'methods'             => 'GET',
				'callback'            => array( new \Growmatik\EDD\Orders(), 'index' ),
				'permission_callback' => $token_verifier_callback,
			)
		);

		register_rest_route(
			$base_route,
			'sync/guest-customers/edd',
			array(
				'methods'             => 'GET',
				'callback'            => array( new \Growmatik\EDD\Guest_Customers_Sync(), 'index' ),
				'permission_callback' => $token_verifier_callback,
			)
		);

		register_rest_route(
			$base_route,
			'coupons/edd',
			array(
				'methods'             => 'POST',
				'callback'            => array( new \Growmatik\EDD\Discounts(), 'index' ),
				'permission_callback' => $token_verifier_callback,
			)
		);

		register_rest_route(
			$base_route,
			'coupons/edd/create',
			array(
				'methods'             => 'POST',
				'callback'            => array( new \Growmatik\EDD\Discounts(), 'add' ),
				'permission_callback' => $token_verifier_callback,
			)
		);

		register_rest_route(
			$base_route,
			'coupons/edd/update',
			array(
				'methods'             => 'POST',
				'callback'            => array( new \Growmatik\EDD\Discounts(), 'add' ),
				'permission_callback' => $token_verifier_callback,
			)
		);

		register_rest_route(
			$base_route,
			'coupons/edd/delete',
			array(
				'methods'             => 'POST',
				'callback'            => array( new \Growmatik\EDD\Discounts(), 'remove' ),
				'permission_callback' => $token_verifier_callback,
			)
		);
	}

}
