<?php

namespace Growmatik\Woocommerce;

class Routes {

	public function __construct() {
		if ( ! \Growmatik\is_woocommerce_active() ) {
			return;
		}

		add_action( 'rest_api_init', array( $this, 'register_routes' ) );
	}

	public function register_routes() {
		$base_route              = 'growmatik/v1';
		$token_verifier_callback = array( new \Growmatik\Webhook\Verify_Token_Webhook(), 'verify_token' );

		register_rest_route(
			$base_route,
			'sync/products/woo',
			array(
				'methods'             => 'GET',
				'callback'            => array( new \Growmatik\Controller\Product_Controller(), 'index' ),
				'permission_callback' => $token_verifier_callback,
			)
		);

		register_rest_route(
			$base_route,
			'sync/orders/woo',
			array(
				'methods'             => 'GET',
				'callback'            => array( new \Growmatik\Controller\Orders_Controller(), 'index' ),
				'permission_callback' => $token_verifier_callback,
			)
		);

		register_rest_route(
			$base_route,
			'sync/guest-customers/woo',
			array(
				'methods'             => 'GET',
				'callback'            => array( new \Growmatik\Woocommerce\Guest_Customers_Sync(), 'index' ),
				'permission_callback' => $token_verifier_callback,
			)
		);

		register_rest_route(
			$base_route,
			'coupons/woo',
			array(
				'methods'             => 'POST',
				'callback'            => array( new \Growmatik\Controller\Coupon_Controller(), 'retrieve' ),
				'permission_callback' => $token_verifier_callback,
			)
		);

		register_rest_route(
			$base_route,
			'coupons/woo/create',
			array(
				'methods'             => 'POST',
				'callback'            => array( new \Growmatik\Controller\Coupon_Controller(), 'create' ),
				'permission_callback' => $token_verifier_callback,
			)
		);

		register_rest_route(
			$base_route,
			'coupons/woo/update',
			array(
				'methods'             => 'POST',
				'callback'            => array( new \Growmatik\Controller\Coupon_Controller(), 'update' ),
				'permission_callback' => $token_verifier_callback,
			)
		);

		register_rest_route(
			$base_route,
			'coupons/woo/delete',
			array(
				'methods'             => 'POST',
				'callback'            => array( new \Growmatik\Controller\Coupon_Controller(), 'delete' ),
				'permission_callback' => $token_verifier_callback,
			)
		);
	}

}
