<?php

namespace Growmatik\Front;

use Growmatik;
use Growmatik\Admin\Integration;
use Growmatik\Page_Content_Details;
use function Growmatik\get_user_identity_token;

class Init {

	public function __construct() {
		add_action( 'wp_enqueue_scripts', array( $this, 'add_growmatik_if_then' ) );
		add_action( 'wp_enqueue_scripts', array( $this, 'add_inline_scripts' ), 9 );
	}

	public function add_growmatik_if_then() {
		wp_enqueue_script( 'growmatik-if-then' );
	}

	public function add_inline_scripts() {
		global $wp;
		$site_id      = get_option( 'growmatik_site_id' );
		$user_type    = Growmatik\get_user_type();
		$current_user = ( 'guest' === $user_type ) ? null : wp_get_current_user();

		$growmatik = array(
			'load'        => true,
			'currentTime' => esc_html( date( 'Y-m-d H:i:s' ) ),
			'platform'    => array(
				'platformKey'  => 'wordpress',
				'growmatikApi' => esc_url( GROWMATIK_API_URL ),
				'env'          => esc_html( GROWMATIK_APP_ENV ),
				'integration'  => Integration::is_paused() ? 'paused' : 'active',
			),
			'siteId'      => esc_html( $site_id ),
			'site'        => array(
				'id'  => esc_html( $site_id ),
				'url' => esc_url( rtrim( site_url(), '/' ) ),
			),
			'page'        => array(
				'pageId'   => get_the_ID(),
				'pageType' => esc_html( Page_Content_Details::get_page_type() ),
				'platform' => esc_html( Page_Content_Details::get_platform() ),
				'url'      => esc_url( '/' . $wp->request ),
				'isSingle' => ( is_single() || is_page() ) ? true : false,
			),
			'user'        => array(
				'type'          => esc_html( $user_type ),
				'email'         => $current_user ? esc_html( $current_user->user_email ) : '',
				// 'siteUserId' => not available
				'userId'        => $current_user ? esc_html( $current_user->ID ) : '',
				'identityToken' => $current_user ? get_user_identity_token( $current_user->ID ) : '',
				'username'      => $current_user ? esc_html( $current_user->user_login ) : '',
				'firstName'     => $current_user ? esc_html( $current_user->first_name ) : '',
				'lastName'      => $current_user ? esc_html( $current_user->last_name ) : '',
				'registeredAt'  => $current_user ? esc_html( $current_user->user_registered ) : '',
			),
			'commerce'    => apply_filters( 'growmatik_data_layer_commerce_entry', array() ),
		);

		wp_localize_script( 'growmatik-if-then', '_growmatik', $growmatik );
	}

}
